// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "browsertab.h"

BrowserTab::BrowserTab(QObject *parent) : QObject(parent) {
	tabButton = new QToolButton();
	content = new WebTab();
	menu = new QMenu();
	acShow = new QAction(tr("Show"), this);
	acEditUrl = new QAction(tr("Edit URL"), this);
	acEditUrl->setCheckable(true);
	acEditUrl->setChecked(true);

	acClose = new QAction(tr("Close"), this);

	menu->addAction(acShow);
	menu->addAction(acEditUrl);
	menu->addSeparator();
	menu->addAction(acClose);

	tabButton->setMenu(menu);
	tabButton->setDefaultAction(acShow);

	tabButton->setText(tr("Empty page"));

	connect(content, SIGNAL(titleChanged(QString)), this, SLOT(setTitle(QString)));

	connect(acShow, SIGNAL(triggered()), this, SLOT(showTab()));
	connect(acEditUrl, SIGNAL(triggered()), content, SLOT(showUrlBar()));
	connect(acClose, SIGNAL(triggered()), this, SLOT(closeTab()));

	connect(content, SIGNAL(urlBarHidden()), this, SLOT(urlBarHidden()));
	connect(content, SIGNAL(isSSL(bool)), this, SLOT(setSSL(bool)));
	connect(content, SIGNAL(sslError()), this, SLOT(setSSLError()));
}

BrowserTab::~BrowserTab() {
	delete content;
	delete acShow;
	delete acEditUrl;

	tabButton->deleteLater();
	menu->deleteLater();
	acClose->deleteLater();
}

bool BrowserTab::isEmptyPage() {
	return content->isEmptyPage();
}

void BrowserTab::back() {
	content->back();
}

void BrowserTab::forward() {
	content->forward();
}

void BrowserTab::stop() {
	content->stop();
}

void BrowserTab::reload() {
	content->reload();
}

void BrowserTab::showTab() {
	emit(selected(content));
}

void BrowserTab::goTo(QString url, bool hideUrlBar) {
	content->goTo(url, hideUrlBar);
}

void BrowserTab::setTitle(QString title) {
	if (title == "") title = tr("Empty Page");
	tabButton->setText(title);
}

void BrowserTab::closeTab() {
	emit(closed(this));
}

void BrowserTab::urlBarHidden() {
	acEditUrl->setChecked(false);
}

void BrowserTab::setSSL(bool sslUsed) {
	ssl = sslUsed;
	sslOk = true;

	QPalette p;
	if (ssl)
		p.setBrush(QPalette::Button, QColor(160,255,160));
	tabButton->setPalette(p);
}

void BrowserTab::setSSLError() {
	sslOk = false;
	QPalette p;
	p.setBrush(QPalette::Button, QColor(255,192,192));
	tabButton->setPalette(p);
}
