// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "lightweight.h"
#include "ui_lightweight.h"

Lightweight::Lightweight(QWidget *parent) : QWidget(parent), ui(new Ui::Lightweight) {
	ui->setupUi(this);

	tabs = new QStackedLayout();
	tabList = new QList<BrowserTab*>();
	ui->verticalLayout->addLayout(tabs);

	ui->verticalLayout->setSpacing(0);
	currentTab = 0;

	bookmarkMenu = new QMenu();
	Bookmark* acnewTab = new Bookmark(QIcon(":/icons/new.png"), "about:blank", tr("Empty Page"));
	acnewTab->hideDeleteButton();
	Bookmark* m = new Bookmark(QIcon(":/icons/logo.png"), "http://www.google.de", "Google");


	bookmarkMenu->addAction(acnewTab);
	bookmarkMenu->addSeparator();
	bookmarkMenu->addAction(m);

	ui->bNewTab->setMenu(bookmarkMenu);
	ui->bNewTab->setDefaultAction(acnewTab);

	connect(bookmarkMenu, SIGNAL(triggered(QAction*)), this, SLOT(openBookmark(QAction*)));
	connect(bookmarkMenu, SIGNAL(triggered(QAction*)), bookmarkMenu, SLOT(hide()));

	connect(ui->bBack, SIGNAL(clicked()), this, SLOT(back()));
	connect(ui->bForward, SIGNAL(clicked()), this, SLOT(forward()));
	connect(ui->bStop, SIGNAL(clicked()), this, SLOT(stop()));
	connect(ui->bReload, SIGNAL(clicked()), this, SLOT(reload()));

	connect(ui->tfSearch, SIGNAL(returnPressed()), this, SLOT(search()));

	ui->cbSearchEngine->addItem(QIcon(":/icons/logo.png"), tr(""), QVariant("http://www.google.de/search?q=%{query}&ie=UTF-8&oe=UTF-8"));
	newTab();
}

Lightweight::~Lightweight() {
	delete ui;
	while (tabList->size() > 0) {
		BrowserTab* tab = tabList->first();
		tabList->removeAll(tab);
		delete tab;
	}
	delete tabList;
}

void Lightweight::newTab(QString url, bool hideUrlBar) {
	BrowserTab* tab = new BrowserTab();
	tabList->append(tab);
	ui->tabcontainer->layout()->addWidget(tab->tabButton);
	tabs->addWidget(tab->content);
	tabs->setCurrentWidget(tab->content);

	currentTab = tab->content;

	tab->goTo(url, hideUrlBar);
	connect(tab, SIGNAL(selected(WebTab*)), this, SLOT(showTab(WebTab*)));
	connect(tab, SIGNAL(closed(BrowserTab*)), this, SLOT(closeTab(BrowserTab*)));
}

void Lightweight::back() {
	currentTab->back();
}

void Lightweight::forward() {
	currentTab->forward();
}

void Lightweight::stop() {
	currentTab->stop();
}

void Lightweight::reload() {
	currentTab->reload();
}

void Lightweight::search() {
	QString queryTemplate = ui->cbSearchEngine->itemData(ui->cbSearchEngine->currentIndex()).toString();

	queryTemplate = queryTemplate.replace("%{query}", ui->tfSearch->text());
	if ((currentTab != 0) && currentTab->isEmptyPage()) currentTab->goTo(queryTemplate);
	else newTab(queryTemplate, true);
}

void Lightweight::showTab(WebTab *tab) {
	tabs->setCurrentWidget(tab);
	currentTab = tab;
}

void Lightweight::closeTab(BrowserTab *tab) {
	tabs->removeWidget(tab->content);
	ui->tabcontainer->layout()->removeWidget(tab->tabButton);

	tabList->removeAll(tab);

	if (!tabList->isEmpty() && (tab->content == currentTab)) {
		showTab(tabList->last()->content);
	}

	if (tabList->isEmpty()) {
		currentTab = 0;
	}

	delete tab;
}

void Lightweight::openBookmark(QAction *ac) {
	Bookmark* b = (Bookmark*) ac;

	if (b->toBeDeleted()) {
		bookmarkMenu->removeAction(ac);
		delete b;
	} else {
		if ((currentTab != 0) && currentTab->isEmptyPage()) currentTab->goTo(b->url());
		else newTab(b->url());
	}
}
