// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "webtab.h"

WebTab::WebTab(QWidget *parent) : QWidget(parent) {

	urlBar = new QLineEdit(this);
	view = new QWebView(this);
	layout = new QVBoxLayout();

	layout->setContentsMargins(0,0,0,0);
	setLayout(layout);
	layout->addWidget(urlBar);
	layout->addWidget(view);

	connect(view, SIGNAL(urlChanged(QUrl)), this, SLOT(showUrl(QUrl)));
	connect(urlBar, SIGNAL(returnPressed()), this, SLOT(loadUrl()));
	connect(view, SIGNAL(titleChanged(QString)), this, SIGNAL(titleChanged(QString)));

	connect(view->page()->networkAccessManager(), SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)), this, SIGNAL(sslError()));
}

WebTab::~WebTab() {
	delete urlBar;
	delete view;
	delete layout;
}

QString WebTab::currentURL() {
	return urlBar->text();
}

bool WebTab::isEmptyPage() {
	return view->url().toString() == "about:blank";
}

void WebTab::back() {
	view->back();
}

void WebTab::forward() {
	view->forward();
}

void WebTab::stop() {
	view->stop();
}

void WebTab::reload() {
	view->reload();
}

void WebTab::showUrlBar() {
	if (urlBar->isVisible()) urlBar->hide();
	else urlBar->show();
}

void WebTab::goTo(QString url, bool hideUrlBar) {
	view->load(QUrl(url));
	if (hideUrlBar) {
		urlBar->hide();
		emit(urlBarHidden());
	}
}

void WebTab::showUrl(QUrl url) {
	QString urlStr = url.toString();
	emit(isSSL(urlStr.startsWith("https")));
	if (urlStr == "about:blank") urlStr = "";
	urlBar->setText(urlStr);
}

void WebTab::loadUrl() {
	QString url = urlBar->text();
	if (!url.startsWith("http://")) url = "http://"+url;
	emit(isSSL(url.startsWith("https")));
	view->load(QUrl(url));
	urlBar->hide();
	emit(urlBarHidden());
}
